@@ -136,7 +136,7 @@ public class MessagingCopyTask implements CopyUserTaskService {
                 setAccountIdsForMessagingAccounts(accounts, accountMapping);
                 writeMessagingAccountsToDB(accounts, dstCon, i(dstCtxId), i(dstUsrId));
             }
-        }  catch (final SQLException e) {
+        }  catch (SQLException e) {
             throw UserCopyExceptionCodes.SQL_PROBLEM.create(e);
         }
 
@@ -154,7 +154,7 @@ public class MessagingCopyTask implements CopyUserTaskService {
                         if (newId != null) {
                             attribute.setValue(String.valueOf(newId));
                         }
-                    } catch (final NumberFormatException e) {
+                    } catch (NumberFormatException e) {
                         // Skip this one
                     }
 
@@ -180,7 +180,7 @@ public class MessagingCopyTask implements CopyUserTaskService {
                 final int newConfigId = IDGenerator.getId(cid, Types.GENERIC_CONFIGURATION, con);
                 account.setConfId(newConfigId);
                 account.setId(newConfigId);
-            } catch (final SQLException e) {
+            } catch (SQLException e) {
                 throw UserCopyExceptionCodes.SQL_PROBLEM.create(e);
             }
         }
@@ -206,7 +206,7 @@ public class MessagingCopyTask implements CopyUserTaskService {
 
                 accounts.add(account);
             }
-        } catch (final SQLException e) {
+        } catch (SQLException e) {
             throw UserCopyExceptionCodes.SQL_PROBLEM.create(e);
         } finally {
             Databases.closeSQLStuff(rs, stmt);
@@ -235,7 +235,7 @@ public class MessagingCopyTask implements CopyUserTaskService {
             }
 
             stmt.executeBatch();
-        } catch (final SQLException e) {
+        } catch (SQLException e) {
             throw UserCopyExceptionCodes.SQL_PROBLEM.create(e);
         } finally {
             Databases.closeSQLStuff(stmt);
